# Historical data for The Rivalry.

# Load data.
laf.le <- read.csv("./laf_le_data.csv", header=TRUE)
attach(laf.le)

# Begin by looking at outcome (1 for Lafayette win, 0 for Lehigh win).
# Perform stepwise selection.
null <- glm(Winner ~ 1, family=binomial, data=laf.le)
full <- glm(Winner ~ Host + LaW2GR + LaWPG + LeW2GR + LeWPG + Host*LaW2GR + Host*LaWPG + Host*LeW2GR + Host*LeWPG + LaW2GR*LaWPG + LaW2GR*LeW2GR + LaW2GR*LeWPG + LaWPG*LeW2GR + LaWPG*LeWPG + LeW2GR*LeWPG, family=binomial, data=laf.le)
search <- step(null, scope=list(upper=full),  family=binomial, data=laf.le, direction="both")

# Do the leave-one-out cross-validation.
glm.1 <- glm(Winner ~ LaW2GR + LaWPG, family=binomial, data=laf.le)
summary(glm.1)
require(boot)
cv.1 <- cv.glm(laf.le, glm.1)
# Get the prediction error.
cv.1$delta
# -> 0.1952618 0.1946513.
# 33*0.1952618 ~= 6.44.

# In 2018, Lafayette won 3 out of 10 games going into the Rivalry. And they lost their preceding game.
LaW2GR.2018 <- c(0.3)
LaWPG.2018 <- c(0)
predict(glm.1, data.frame(LaW2GR = LaW2GR.2018, LaWPG = LaWPG.2018), type = "response")

-4.5594 + 5.6628*0.3 + 1.7490*0
exp(-2.86056)/(1 + exp(-2.86056))
# 0.05414 closer to 0, so predicts Lafayette loss.

-4.5594 + 5.6628*0.7 + 1.7490*1
exp(1.15356)/(1 + exp(1.15356))
# Artificial example of a predicted Lafayette win.


# Now look at win margin (negative for Lafayette winning by a certain amount, positive for Lehigh winning by a certain amount).
null <- glm(WinMargin ~ 1, family=gaussian, data=laf.le)
full <- glm(WinMargin ~ Host + LaW2GR + LaWPG + LeW2GR + LeWPG + Host*LaW2GR + Host*LaWPG + Host*LeW2GR + Host*LeWPG + LaW2GR*LaWPG + LaW2GR*LeW2GR + LaW2GR*LeWPG + LaWPG*LeW2GR + LaWPG*LeWPG + LeW2GR*LeWPG, family=gaussian, data=laf.le)
search <- step(null, scope=list(upper=full),  family=binomial, data=laf.le, direction="both")

# Do the leave-one-out cross-validation.
glm.2 <- glm(WinMargin ~ LaW2GR, family=gaussian, data=laf.le)
summary(glm.2)
cv.2 <- cv.glm(laf.le, glm.2)
# Get the prediction error.
cv.2$delta
# -> 223.1168 222.7935.

pred <- predict(glm.2, data.frame(LaW2GR = LaW2GR.2018), type = "response", se.fit = TRUE)
# -11.96449 ~= -12 points.
# se = 3.460984.
n <- length(LaW2GR)
critical <- qt(.975, n - 2)
upr <- pred$fit + critical*pred$se.fit
lwr <- pred$fit - critical*pred$se.fit
plot(LaW2GR, WinMargin)
